# TekWFM2
Parser for Tektronix WFM v.2 binary files

Module reads volts vs. time records (including fastframes) from little-endian version 2 WFM files

ScopeData interface is unified with [LeCroyParser](https://github.com/bennomeier/leCroyParser) interface.
